document.addEventListener('DOMContentLoaded', function() {
  const urlInput = document.getElementById('urlInput');
  const generateBtn = document.getElementById('generateBtn');
  const qrcodeDiv = document.getElementById('qrcode');
  
  const wordFile = document.getElementById('wordFile');
  const preview = document.getElementById('preview');
  const downloadBtn = document.getElementById('downloadBtn');
  
  let qr = null;
  let convertedHtml = '';

  const tabs = document.querySelectorAll('.tablinks');
  const tabContents = document.querySelectorAll('.tabcontent');
  
  function switchTab(tabName) {
    // 移除所有标签的激活状态
    tabs.forEach(tab => tab.classList.remove('active'));
    
    // 隐藏所有内容
    tabContents.forEach(content => {
      content.style.display = 'none';
    });
    
    // 激活选中的标签
    const selectedTab = document.querySelector(`[data-tab="${tabName}"]`);
    if (selectedTab) {
      selectedTab.classList.add('active');
    }
    
    // 显示对应内容
    const selectedContent = document.getElementById(tabName);
    if (selectedContent) {
      selectedContent.style.display = 'block';
    }
  }
  
  // 为每个标签添加点击事件
  tabs.forEach(tab => {
    tab.addEventListener('click', (e) => {
      const tabName = e.currentTarget.getAttribute('data-tab');
      if (tabName) {
        switchTab(tabName);
      }
    });
  });

  // 初始化显示第一个标签页
  switchTab('qr');

  chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
    if (tabs[0] && tabs[0].url) {
      urlInput.value = tabs[0].url;
      generateQRCode(tabs[0].url);
    }
  });

  generateBtn.addEventListener('click', function() {
    generateQRCode(urlInput.value);
  });

  function generateQRCode(text) {
    if (!text) return;
    
    qrcodeDiv.innerHTML = '';
    qr = new QRCode(qrcodeDiv, {
      text: text,
      width: 256,
      height: 256,
      colorDark: "#000000",
      colorLight: "#ffffff",
      correctLevel: QRCode.CorrectLevel.H
    });
  }

  // Word转HTML功能
  const fileNameDisplay = document.getElementById('fileNameDisplay');
  const convertStatus = document.getElementById('convertStatus');

  let currentFileName = '';

  wordFile.addEventListener('change', function(e) {
    const file = e.target.files[0];
    if (file) {
      currentFileName = file.name.replace(/\.docx$/i, '');
      fileNameDisplay.innerHTML = `
        <span class="file-name" title="${file.name}">
          📄 ${file.name}
        </span>
      `;
      
      showStatus('loading', '正在转换中...');

      const reader = new FileReader();
      reader.onload = function(e) {
        mammoth.convertToHtml({arrayBuffer: e.target.result})
          .then(function(result) {
            convertedHtml = result.value;
            preview.innerHTML = convertedHtml;
            downloadBtn.style.display = 'block';
            showStatus('success', '转换成功！');
          })
          .catch(function(error) {
            console.error(error);
            showStatus('error', '转换失败：' + error.message);
          });
      };
      reader.readAsArrayBuffer(file);
    }
  });

  function showStatus(type, message) {
    convertStatus.className = 'status-message ' + type;
    convertStatus.textContent = message;
    
    if (type === 'success') {
      setTimeout(() => {
        convertStatus.style.display = 'none';
      }, 3000);
    }
  }

  downloadBtn.addEventListener('click', function() {
    if (!convertedHtml) return;

    const fullHtml = `
      <!DOCTYPE html>
      <html>
      <head>
        <meta charset="UTF-8">
        <title>${currentFileName}</title>
        <style>
          body { font-family: Arial, sans-serif; line-height: 1.6; }
        </style>
      </head>
      <body>
        ${convertedHtml}
      </body>
      </html>
    `;

    const blob = new Blob([fullHtml], {type: 'text/html'});
    const url = URL.createObjectURL(blob);
    
    chrome.downloads.download({
      url: url,
      filename: `${currentFileName}.html`,
      saveAs: true
    });
  });

  // 添加百度翻译API配置
  const BAIDU_APPID = '20241112002200806';
  const BAIDU_KEY = 'preM0becByYCdotRTP_a';

  let wordTranslateFile = null;

  document.getElementById('wordTranslateFile').addEventListener('change', async (e) => {
    const file = e.target.files[0];
    if (file) {
      wordTranslateFile = file;
      document.getElementById('translateFileNameDisplay').textContent = file.name;
      document.getElementById('translateBtn').style.display = 'block';
    }
  });

  document.getElementById('translateBtn').addEventListener('click', async () => {
    if (!wordTranslateFile) return;
    
    const translateBtn = document.getElementById('translateBtn');
    const translateStatus = document.getElementById('translateStatus');
    const progressBar = document.querySelector('.progress-bar');
    const progressContainer = document.querySelector('.progress-container');
    const progressText = document.getElementById('progressText');
    
    // 禁用翻译按钮
    translateBtn.disabled = true;
    translateBtn.style.opacity = '0.6';
    translateBtn.textContent = '翻译中...';
    
    translateStatus.textContent = '正在处理文档...';
    progressContainer.style.display = 'block';
    progressText.style.display = 'block';
    progressBar.style.width = '0%';
    
    // 进度检查变量
    let lastProgress = 0;
    let noProgressCount = 0;
    
    try {
      const formData = new FormData();
      formData.append('file', wordTranslateFile);
      formData.append('target_lang', document.getElementById('targetLang').value);
      
      // 开始翻译请求
      const response = await fetch('http://localhost:5000/translate', {
        method: 'POST',
        body: formData
      });
      
      // 定时检查进度
      const progressCheck = setInterval(async () => {
        try {
          const progressResponse = await fetch('http://localhost:5000/progress');
          const progressData = await progressResponse.json();
          
          // 检查进度是否停滞
          if (progressData.progress === lastProgress) {
            noProgressCount++;
            if (noProgressCount > 10) { // 5秒无进度更新
              clearInterval(progressCheck);
              throw new Error('翻译进度停滞，请重试');
            }
          } else {
            noProgressCount = 0;
            lastProgress = progressData.progress;
          }
          
          progressBar.style.width = `${progressData.progress}%`;
          progressText.textContent = `翻译进度: ${progressData.progress}%`;
        } catch (error) {
          clearInterval(progressCheck);
          throw error;
        }
      }, 500);
      
      if (!response.ok) {
        clearInterval(progressCheck);
        const error = await response.json();
        throw new Error(error.error || '翻译失败');
      }
      
      // 下载翻译后的文件
      const blob = await response.blob();
      clearInterval(progressCheck);
      
      const url = URL.createObjectURL(blob);
      const a = document.createElement('a');
      a.href = url;
      a.download = `translated_${wordTranslateFile.name}`;
      a.click();
      
      translateStatus.textContent = '翻译完成！';
      progressBar.style.width = '100%';
      
      // 重置按钮状态
      setTimeout(() => {
        translateBtn.disabled = false;
        translateBtn.style.opacity = '1';
        translateBtn.innerHTML = '<span class="icon">🔄</span>开始翻译';
        progressContainer.style.display = 'none';
        progressText.style.display = 'none';
      }, 2000);
      
    } catch (error) {
      translateStatus.textContent = '翻译失败：' + error.message;
      progressContainer.style.display = 'none';
      progressText.style.display = 'none';
      
      // 重置按钮状态
      translateBtn.disabled = false;
      translateBtn.style.opacity = '1';
      translateBtn.innerHTML = '<span class="icon">🔄</span>开始翻译';
    }
  });

  // MD5函数实现
  function MD5(string) {
    // 实现MD5加密
    // 可以使用第三方库如crypto-js
  }
}); 